==> nextcloud-26.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/es.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La contraseña ha caducado. Por favor, usa el método de contraseña olvidada para resetearla.",
    "Password must not have been used recently before." : "La contraseña no debe haber sido utilizada recientemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contraseña está entre el millón más común. Por favor, elige una diferente.",
    "Password is present in compromised password list. Please choose a different password." : "La contraseña se encuentra en una lista de contraseñas filtradas. Por favor, escoge una contraseña diferente.",
    "Password needs to be at least %s characters long." : "La contraseña debe tener un mínimo de %s caracteres.",
    "Password needs to contain at least one numeric character." : "La contraseña debe contener al menos un número.",
    "Password needs to contain at least one special character." : "La contraseña debe contener al menos un carácter especial.",
    "Password needs to contain at least one lower and one upper case character." : "La contraseña debe contener al menos una minúscula y una mayúscula.",
    "Password policy" : "Política de contraseñas",
    "Allows admins to configure a password policy" : "Permite a los administradores configurar una política de contraseñas",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permite a los administradores definir ciertas precondiciones para las contraseñas, p. ej., obligar a una longitud mínima",
    "Minimum password length" : "Longitud mínima de la contraseña",
    "User password history" : "Histórico de contraseñas del usuario",
    "Number of days until user password expires" : "Número de días hasta que la contraseña caduque",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Número de intentos de inicio de sesión antes de que la cuenta se bloquee (0 para que no haya límite)",
    "Forbid common passwords" : "Prohibir contraseñas comunes",
    "Enforce upper and lower case characters" : "Imponer caracteres en mayúsculas y minúsculas",
    "Enforce numeric characters" : "Imponer caracteres numéricos",
    "Enforce special characters" : "Imponer caracteres especiales",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar contraseña en la lista de contraseñas filtradas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un hash de las contraseñas y envía los 5 primeros caracteres de este hash a la API de haveibeenpwned.com para recuperar una lista de todos los hashes que comienzan de esa forma. Después se comprueba en la instancia de Nextcloud si el hash de la contraseña está en el conjunto de resultados.",
    "Unknown error" : "Error desconocido",
    "Minimal length has to be a non negative number" : "La longitud mínima no puede ser un número negativo",
    "History size has to be a non negative number" : "El tamaño del histórico no puede ser un número negativo",
    "Expiration days have to be a non negative number" : "Los días de caducidad no pueden ser un número negativo",
    "Maximum login attempts have to be a non negative number" : "El número máximo de intentos de inicio de sesión no puede ser un número negativo",
    "Settings saved" : "Ajustes guardados",
    "Error while saving settings" : "Error al guardar las configuraciones",
    "Saved" : "Guardado",
    "Error while saving" : "Error al guardar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-26.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/es.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La contraseña ha caducado. Por favor, usa el método de contraseña olvidada para resetearla.",
    "Password must not have been used recently before." : "La contraseña no debe haber sido utilizada recientemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contraseña está entre el millón más común. Por favor, elige una diferente.",
    "Password is present in compromised password list. Please choose a different password." : "La contraseña se encuentra en una lista de contraseñas filtradas. Por favor, escoge una contraseña diferente.",
    "Password needs to be at least %s characters long." : "La contraseña debe tener un mínimo de %s caracteres.",
    "Password needs to contain at least one numeric character." : "La contraseña debe contener al menos un número.",
    "Password needs to contain at least one special character." : "La contraseña debe contener al menos un carácter especial.",
    "Password needs to contain at least one lower and one upper case character." : "La contraseña debe contener al menos una minúscula y una mayúscula.",
    "Password policy" : "Política de contraseñas",
    "Allows admins to configure a password policy" : "Permite a los administradores configurar una política de contraseñas",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permite a los administradores definir ciertas precondiciones para las contraseñas, p. ej., obligar a una longitud mínima",
    "Minimum password length" : "Longitud mínima de la contraseña",
    "User password history" : "Histórico de contraseñas del usuario",
    "Number of days until user password expires" : "Número de días hasta que la contraseña caduque",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Número de intentos de inicio de sesión antes de que la cuenta se bloquee (0 para que no haya límite)",
    "Forbid common passwords" : "Prohibir contraseñas comunes",
    "Enforce upper and lower case characters" : "Hacer obligatorio el uso de caracteres en mayúsculas y minúsculas",
    "Enforce numeric characters" : "Hacer obligatorio el uso de caracteres numéricos",
    "Enforce special characters" : "Hacer obligatorio el uso de caracteres especiales",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar contraseña en la lista de contraseñas filtradas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un hash de las contraseñas y envía los 5 primeros caracteres de este hash a la API de haveibeenpwned.com para recuperar una lista de todos los hashes que comienzan de esa forma. Después se comprueba en la instancia de Nextcloud si el hash de la contraseña está en el conjunto de resultados.",
    "Unknown error" : "Error desconocido",
    "Minimal length has to be a non negative number" : "La longitud mínima no puede ser un número negativo",
    "History size has to be a non negative number" : "El tamaño del histórico no puede ser un número negativo",
    "Expiration days have to be a non negative number" : "Los días de caducidad no pueden ser un número negativo",
    "Maximum login attempts have to be a non negative number" : "El número máximo de intentos de inicio de sesión no puede ser un número negativo",
    "Settings saved" : "Ajustes guardados",
    "Error while saving settings" : "Error al guardar las configuraciones",
    "Saved" : "Guardado",
    "Error while saving" : "Error al guardar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
